@@ -1,7 +1,8 @@
 """For deserializing the json responses"""
 import abc
-import re
 import math
+from collections import OrderedDict
+import re
 
 from blaseball_mike import database, tables
 
@@ -409,6 +410,10 @@ class Division(Base):
 
 class Subleague(Base):
 
+    def __init__(self, data):
+        super().__init__(data)
+        self._teams = {}
+
     @classmethod
     def load(cls, id_):
         return cls(database.get_subleague(id_))
@@ -425,9 +430,21 @@ class Subleague(Base):
         self._divisions = None
         self._division_ids = value
 
+    @property
+    def teams(self):
+        if self._teams:
+            return self._teams
+        for division in self.divisions.values():
+            self._teams.update(division.teams)
+        return self._teams
+
 
 class League(Base):
 
+    def __init__(self, data):
+        super().__init__(data)
+        self._teams = {}
+
     @classmethod
     def load(cls):
         return cls(database.get_league())
@@ -448,6 +465,14 @@ class League(Base):
         self._subleagues = None
         self._subleague_ids = value
 
+    @property
+    def teams(self):
+        if self._teams:
+            return self._teams
+        for subleague in self.subleagues.values():
+            self._teams.update(subleague.teams)
+        return self._teams
+
 
 class Game(Base):
 
@@ -831,3 +856,21 @@ class Season(Base):
     def standings(self, value):
         self._standings = None
         self._standings_id = value
+
+
+class Idol(Base):
+
+    @classmethod
+    def load(cls):
+        idols = database.get_idols()
+        idols_dict = OrderedDict()
+        for idol in idols:
+            idols_dict[idol['id']] = cls(idol)
+        return idols_dict
+
+    @property
+    def player(self):
+        if self._player:
+            return self._player
+        self._player = Player.load_one(self.player_id)
+        return self._player
