@@ -5,6 +5,7 @@ import asyncio
 
 from blaseball_mike.events import stream_events
 from blaseball_mike.models import Game
+from blaseball_mike.stream_model import StreamData
 
 
 async def test_stream():
@@ -17,9 +18,15 @@ async def test_stream():
         print(schedule)
 
 
+async def test_stream_data():
+    async for event in stream_events():
+        payload = StreamData(event)
+        print(payload)
+
+
 def test():
     loop = asyncio.get_event_loop()
-    loop.create_task(test_stream())
+    loop.create_task(test_stream_data())
     loop.run_forever()
 
 
